@@ -182,6 +182,11 @@ fn main() {
     Ok(())
   });
 
+  listener.on_update_have_pending_notifications(|(_api, update)| {
+    debug!("have pending notifications {:?}", update);
+    Ok(())
+  });
+
   listener.on_update_scope_notification_settings(|(_api, update)| {
     debug!("scope notification settings {:?}", update);
     Ok(())
@@ -239,7 +244,10 @@ fn main() {
     }
     api.download_file(DownloadFile::builder()
       .file_id(file.id())
+      .offset(0)
+      .limit(0)
       .priority(1)
+      .synchronous(false)
       .build())
       .unwrap();
     Ok(())
