@@ -61,6 +61,11 @@ impl AsyncApi {
     async_caller(&self.api, add_chat_members.as_ref()).await
   }
 
+  pub async fn add_custom_server_language_pack<C: AsRef<AddCustomServerLanguagePack>>(&self, add_custom_server_language_pack: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, add_custom_server_language_pack.as_ref()).await
+  }
+
   pub async fn add_favorite_sticker<C: AsRef<AddFavoriteSticker>>(&self, add_favorite_sticker: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, add_favorite_sticker.as_ref()).await
@@ -71,6 +76,11 @@ impl AsyncApi {
     async_caller(&self.api, add_local_message.as_ref()).await
   }
 
+  pub async fn add_log_message<C: AsRef<AddLogMessage>>(&self, add_log_message: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, add_log_message.as_ref()).await
+  }
+
   pub async fn add_network_statistics<C: AsRef<AddNetworkStatistics>>(&self, add_network_statistics: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, add_network_statistics.as_ref()).await
@@ -211,6 +221,11 @@ impl AsyncApi {
     async_caller(&self.api, check_phone_number_verification_code.as_ref()).await
   }
 
+  pub async fn check_recovery_email_address_code<C: AsRef<CheckRecoveryEmailAddressCode>>(&self, check_recovery_email_address_code: C) -> RTDResult<PasswordState> {
+    async_caller!(PasswordState);
+    async_caller(&self.api, check_recovery_email_address_code.as_ref()).await
+  }
+
   pub async fn clean_file_name<C: AsRef<CleanFileName>>(&self, clean_file_name: C) -> RTDResult<Text> {
     async_caller!(Text);
     async_caller(&self.api, clean_file_name.as_ref()).await
@@ -491,6 +506,11 @@ impl AsyncApi {
     async_caller(&self.api, get_all_passport_elements.as_ref()).await
   }
 
+  pub async fn get_application_config<C: AsRef<GetApplicationConfig>>(&self, get_application_config: C) -> RTDResult<JsonValue> {
+    async_caller!(JsonValue);
+    async_caller(&self.api, get_application_config.as_ref()).await
+  }
+
   pub async fn get_archived_sticker_sets<C: AsRef<GetArchivedStickerSets>>(&self, get_archived_sticker_sets: C) -> RTDResult<StickerSets> {
     async_caller!(StickerSets);
     async_caller(&self.api, get_archived_sticker_sets.as_ref()).await
@@ -561,6 +581,11 @@ impl AsyncApi {
     async_caller(&self.api, get_chat_message_count.as_ref()).await
   }
 
+  pub async fn get_chat_notification_settings_exceptions<C: AsRef<GetChatNotificationSettingsExceptions>>(&self, get_chat_notification_settings_exceptions: C) -> RTDResult<Chats> {
+    async_caller!(Chats);
+    async_caller(&self.api, get_chat_notification_settings_exceptions.as_ref()).await
+  }
+
   pub async fn get_chat_pinned_message<C: AsRef<GetChatPinnedMessage>>(&self, get_chat_pinned_message: C) -> RTDResult<Message> {
     async_caller!(Message);
     async_caller(&self.api, get_chat_pinned_message.as_ref()).await
@@ -571,6 +596,11 @@ impl AsyncApi {
     async_caller(&self.api, get_chat_report_spam_state.as_ref()).await
   }
 
+  pub async fn get_chat_statistics_url<C: AsRef<GetChatStatisticsUrl>>(&self, get_chat_statistics_url: C) -> RTDResult<HttpUrl> {
+    async_caller!(HttpUrl);
+    async_caller(&self.api, get_chat_statistics_url.as_ref()).await
+  }
+
   pub async fn get_chats<C: AsRef<GetChats>>(&self, get_chats: C) -> RTDResult<Chats> {
     async_caller!(Chats);
     async_caller(&self.api, get_chats.as_ref()).await
@@ -596,6 +626,16 @@ impl AsyncApi {
     async_caller(&self.api, get_created_public_chats.as_ref()).await
   }
 
+  pub async fn get_current_state<C: AsRef<GetCurrentState>>(&self, get_current_state: C) -> RTDResult<Updates> {
+    async_caller!(Updates);
+    async_caller(&self.api, get_current_state.as_ref()).await
+  }
+
+  pub async fn get_database_statistics<C: AsRef<GetDatabaseStatistics>>(&self, get_database_statistics: C) -> RTDResult<DatabaseStatistics> {
+    async_caller!(DatabaseStatistics);
+    async_caller(&self.api, get_database_statistics.as_ref()).await
+  }
+
   pub async fn get_deep_link_info<C: AsRef<GetDeepLinkInfo>>(&self, get_deep_link_info: C) -> RTDResult<DeepLinkInfo> {
     async_caller!(DeepLinkInfo);
     async_caller(&self.api, get_deep_link_info.as_ref()).await
@@ -611,6 +651,11 @@ impl AsyncApi {
     async_caller(&self.api, get_file.as_ref()).await
   }
 
+  pub async fn get_file_downloaded_prefix_size<C: AsRef<GetFileDownloadedPrefixSize>>(&self, get_file_downloaded_prefix_size: C) -> RTDResult<Count> {
+    async_caller!(Count);
+    async_caller(&self.api, get_file_downloaded_prefix_size.as_ref()).await
+  }
+
   pub async fn get_file_extension<C: AsRef<GetFileExtension>>(&self, get_file_extension: C) -> RTDResult<Text> {
     async_caller!(Text);
     async_caller(&self.api, get_file_extension.as_ref()).await
@@ -656,6 +701,21 @@ impl AsyncApi {
     async_caller(&self.api, get_invite_text.as_ref()).await
   }
 
+  pub async fn get_json_string<C: AsRef<GetJsonString>>(&self, get_json_string: C) -> RTDResult<Text> {
+    async_caller!(Text);
+    async_caller(&self.api, get_json_string.as_ref()).await
+  }
+
+  pub async fn get_json_value<C: AsRef<GetJsonValue>>(&self, get_json_value: C) -> RTDResult<JsonValue> {
+    async_caller!(JsonValue);
+    async_caller(&self.api, get_json_value.as_ref()).await
+  }
+
+  pub async fn get_language_pack_info<C: AsRef<GetLanguagePackInfo>>(&self, get_language_pack_info: C) -> RTDResult<LanguagePackInfo> {
+    async_caller!(LanguagePackInfo);
+    async_caller(&self.api, get_language_pack_info.as_ref()).await
+  }
+
   pub async fn get_language_pack_string<C: AsRef<GetLanguagePackString>>(&self, get_language_pack_string: C) -> RTDResult<LanguagePackStringValue> {
     async_caller!(LanguagePackStringValue);
     async_caller(&self.api, get_language_pack_string.as_ref()).await
@@ -671,6 +731,26 @@ impl AsyncApi {
     async_caller(&self.api, get_localization_target_info.as_ref()).await
   }
 
+  pub async fn get_log_stream<C: AsRef<GetLogStream>>(&self, get_log_stream: C) -> RTDResult<LogStream> {
+    async_caller!(LogStream);
+    async_caller(&self.api, get_log_stream.as_ref()).await
+  }
+
+  pub async fn get_log_tag_verbosity_level<C: AsRef<GetLogTagVerbosityLevel>>(&self, get_log_tag_verbosity_level: C) -> RTDResult<LogVerbosityLevel> {
+    async_caller!(LogVerbosityLevel);
+    async_caller(&self.api, get_log_tag_verbosity_level.as_ref()).await
+  }
+
+  pub async fn get_log_tags<C: AsRef<GetLogTags>>(&self, get_log_tags: C) -> RTDResult<LogTags> {
+    async_caller!(LogTags);
+    async_caller(&self.api, get_log_tags.as_ref()).await
+  }
+
+  pub async fn get_log_verbosity_level<C: AsRef<GetLogVerbosityLevel>>(&self, get_log_verbosity_level: C) -> RTDResult<LogVerbosityLevel> {
+    async_caller!(LogVerbosityLevel);
+    async_caller(&self.api, get_log_verbosity_level.as_ref()).await
+  }
+
   pub async fn get_map_thumbnail_file<C: AsRef<GetMapThumbnailFile>>(&self, get_map_thumbnail_file: C) -> RTDResult<File> {
     async_caller!(File);
     async_caller(&self.api, get_map_thumbnail_file.as_ref()).await
@@ -686,6 +766,16 @@ impl AsyncApi {
     async_caller(&self.api, get_message.as_ref()).await
   }
 
+  pub async fn get_message_link<C: AsRef<GetMessageLink>>(&self, get_message_link: C) -> RTDResult<HttpUrl> {
+    async_caller!(HttpUrl);
+    async_caller(&self.api, get_message_link.as_ref()).await
+  }
+
+  pub async fn get_message_locally<C: AsRef<GetMessageLocally>>(&self, get_message_locally: C) -> RTDResult<Message> {
+    async_caller!(Message);
+    async_caller(&self.api, get_message_locally.as_ref()).await
+  }
+
   pub async fn get_messages<C: AsRef<GetMessages>>(&self, get_messages: C) -> RTDResult<Messages> {
     async_caller!(Messages);
     async_caller(&self.api, get_messages.as_ref()).await
@@ -706,6 +796,11 @@ impl AsyncApi {
     async_caller(&self.api, get_passport_authorization_form.as_ref()).await
   }
 
+  pub async fn get_passport_authorization_form_available_elements<C: AsRef<GetPassportAuthorizationFormAvailableElements>>(&self, get_passport_authorization_form_available_elements: C) -> RTDResult<PassportElementsWithErrors> {
+    async_caller!(PassportElementsWithErrors);
+    async_caller(&self.api, get_passport_authorization_form_available_elements.as_ref()).await
+  }
+
   pub async fn get_passport_element<C: AsRef<GetPassportElement>>(&self, get_passport_element: C) -> RTDResult<PassportElement> {
     async_caller!(PassportElement);
     async_caller(&self.api, get_passport_element.as_ref()).await
@@ -746,6 +841,11 @@ impl AsyncApi {
     async_caller(&self.api, get_public_message_link.as_ref()).await
   }
 
+  pub async fn get_push_receiver_id<C: AsRef<GetPushReceiverId>>(&self, get_push_receiver_id: C) -> RTDResult<PushReceiverId> {
+    async_caller!(PushReceiverId);
+    async_caller(&self.api, get_push_receiver_id.as_ref()).await
+  }
+
   pub async fn get_recent_inline_bots<C: AsRef<GetRecentInlineBots>>(&self, get_recent_inline_bots: C) -> RTDResult<Users> {
     async_caller!(Users);
     async_caller(&self.api, get_recent_inline_bots.as_ref()).await
@@ -941,9 +1041,9 @@ impl AsyncApi {
     async_caller(&self.api, parse_text_entities.as_ref()).await
   }
 
-  pub async fn pin_supergroup_message<C: AsRef<PinSupergroupMessage>>(&self, pin_supergroup_message: C) -> RTDResult<Ok> {
+  pub async fn pin_chat_message<C: AsRef<PinChatMessage>>(&self, pin_chat_message: C) -> RTDResult<Ok> {
     async_caller!(Ok);
-    async_caller(&self.api, pin_supergroup_message.as_ref()).await
+    async_caller(&self.api, pin_chat_message.as_ref()).await
   }
 
   pub async fn ping_proxy<C: AsRef<PingProxy>>(&self, ping_proxy: C) -> RTDResult<Seconds> {
@@ -951,9 +1051,9 @@ impl AsyncApi {
     async_caller(&self.api, ping_proxy.as_ref()).await
   }
 
-  pub async fn process_dc_update<C: AsRef<ProcessDcUpdate>>(&self, process_dc_update: C) -> RTDResult<Ok> {
+  pub async fn process_push_notification<C: AsRef<ProcessPushNotification>>(&self, process_push_notification: C) -> RTDResult<Ok> {
     async_caller!(Ok);
-    async_caller(&self.api, process_dc_update.as_ref()).await
+    async_caller(&self.api, process_push_notification.as_ref()).await
   }
 
   pub async fn read_all_chat_mentions<C: AsRef<ReadAllChatMentions>>(&self, read_all_chat_mentions: C) -> RTDResult<Ok> {
@@ -961,6 +1061,11 @@ impl AsyncApi {
     async_caller(&self.api, read_all_chat_mentions.as_ref()).await
   }
 
+  pub async fn read_file_part<C: AsRef<ReadFilePart>>(&self, read_file_part: C) -> RTDResult<FilePart> {
+    async_caller!(FilePart);
+    async_caller(&self.api, read_file_part.as_ref()).await
+  }
+
   pub async fn recover_authentication_password<C: AsRef<RecoverAuthenticationPassword>>(&self, recover_authentication_password: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, recover_authentication_password.as_ref()).await
@@ -971,8 +1076,8 @@ impl AsyncApi {
     async_caller(&self.api, recover_password.as_ref()).await
   }
 
-  pub async fn register_device<C: AsRef<RegisterDevice>>(&self, register_device: C) -> RTDResult<Ok> {
-    async_caller!(Ok);
+  pub async fn register_device<C: AsRef<RegisterDevice>>(&self, register_device: C) -> RTDResult<PushReceiverId> {
+    async_caller!(PushReceiverId);
     async_caller(&self.api, register_device.as_ref()).await
   }
 
@@ -986,6 +1091,16 @@ impl AsyncApi {
     async_caller(&self.api, remove_favorite_sticker.as_ref()).await
   }
 
+  pub async fn remove_notification<C: AsRef<RemoveNotification>>(&self, remove_notification: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, remove_notification.as_ref()).await
+  }
+
+  pub async fn remove_notification_group<C: AsRef<RemoveNotificationGroup>>(&self, remove_notification_group: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, remove_notification_group.as_ref()).await
+  }
+
   pub async fn remove_proxy<C: AsRef<RemoveProxy>>(&self, remove_proxy: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, remove_proxy.as_ref()).await
@@ -1071,6 +1186,11 @@ impl AsyncApi {
     async_caller(&self.api, resend_phone_number_verification_code.as_ref()).await
   }
 
+  pub async fn resend_recovery_email_address_code<C: AsRef<ResendRecoveryEmailAddressCode>>(&self, resend_recovery_email_address_code: C) -> RTDResult<PasswordState> {
+    async_caller!(PasswordState);
+    async_caller(&self.api, resend_recovery_email_address_code.as_ref()).await
+  }
+
   pub async fn reset_all_notification_settings<C: AsRef<ResetAllNotificationSettings>>(&self, reset_all_notification_settings: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, reset_all_notification_settings.as_ref()).await
@@ -1081,6 +1201,11 @@ impl AsyncApi {
     async_caller(&self.api, reset_network_statistics.as_ref()).await
   }
 
+  pub async fn save_application_log_event<C: AsRef<SaveApplicationLogEvent>>(&self, save_application_log_event: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, save_application_log_event.as_ref()).await
+  }
+
   pub async fn search_call_messages<C: AsRef<SearchCallMessages>>(&self, search_call_messages: C) -> RTDResult<Messages> {
     async_caller!(Messages);
     async_caller(&self.api, search_call_messages.as_ref()).await
@@ -1321,6 +1446,21 @@ impl AsyncApi {
     async_caller(&self.api, set_inline_game_score.as_ref()).await
   }
 
+  pub async fn set_log_stream<C: AsRef<SetLogStream>>(&self, set_log_stream: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_log_stream.as_ref()).await
+  }
+
+  pub async fn set_log_tag_verbosity_level<C: AsRef<SetLogTagVerbosityLevel>>(&self, set_log_tag_verbosity_level: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_log_tag_verbosity_level.as_ref()).await
+  }
+
+  pub async fn set_log_verbosity_level<C: AsRef<SetLogVerbosityLevel>>(&self, set_log_verbosity_level: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_log_verbosity_level.as_ref()).await
+  }
+
   pub async fn set_name<C: AsRef<SetName>>(&self, set_name: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_name.as_ref()).await
@@ -1356,6 +1496,11 @@ impl AsyncApi {
     async_caller(&self.api, set_pinned_chats.as_ref()).await
   }
 
+  pub async fn set_poll_answer<C: AsRef<SetPollAnswer>>(&self, set_poll_answer: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_poll_answer.as_ref()).await
+  }
+
   pub async fn set_profile_photo<C: AsRef<SetProfilePhoto>>(&self, set_profile_photo: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_profile_photo.as_ref()).await
@@ -1406,6 +1551,16 @@ impl AsyncApi {
     async_caller(&self.api, set_username.as_ref()).await
   }
 
+  pub async fn stop_poll<C: AsRef<StopPoll>>(&self, stop_poll: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, stop_poll.as_ref()).await
+  }
+
+  pub async fn synchronize_language_pack<C: AsRef<SynchronizeLanguagePack>>(&self, synchronize_language_pack: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, synchronize_language_pack.as_ref()).await
+  }
+
   pub async fn terminate_all_other_sessions<C: AsRef<TerminateAllOtherSessions>>(&self, terminate_all_other_sessions: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, terminate_all_other_sessions.as_ref()).await
@@ -1516,9 +1671,9 @@ impl AsyncApi {
     async_caller(&self.api, unblock_user.as_ref()).await
   }
 
-  pub async fn unpin_supergroup_message<C: AsRef<UnpinSupergroupMessage>>(&self, unpin_supergroup_message: C) -> RTDResult<Ok> {
+  pub async fn unpin_chat_message<C: AsRef<UnpinChatMessage>>(&self, unpin_chat_message: C) -> RTDResult<Ok> {
     async_caller!(Ok);
-    async_caller(&self.api, unpin_supergroup_message.as_ref()).await
+    async_caller(&self.api, unpin_chat_message.as_ref()).await
   }
 
   pub async fn upgrade_basic_group_chat_to_supergroup_chat<C: AsRef<UpgradeBasicGroupChatToSupergroupChat>>(&self, upgrade_basic_group_chat_to_supergroup_chat: C) -> RTDResult<Chat> {
@@ -1551,6 +1706,11 @@ impl AsyncApi {
     async_caller(&self.api, view_trending_sticker_sets.as_ref()).await
   }
 
+  pub async fn write_generated_file_part<C: AsRef<WriteGeneratedFilePart>>(&self, write_generated_file_part: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, write_generated_file_part.as_ref()).await
+  }
+
 
 }
 
