@@ -37,6 +37,10 @@ impl EventApi {
     self.api.send(add_chat_members.as_ref())
   }
 
+  pub fn add_custom_server_language_pack<C: AsRef<AddCustomServerLanguagePack>>(&self, add_custom_server_language_pack: C) -> RTDResult<()> {
+    self.api.send(add_custom_server_language_pack.as_ref())
+  }
+
   pub fn add_favorite_sticker<C: AsRef<AddFavoriteSticker>>(&self, add_favorite_sticker: C) -> RTDResult<()> {
     self.api.send(add_favorite_sticker.as_ref())
   }
@@ -45,6 +49,10 @@ impl EventApi {
     self.api.send(add_local_message.as_ref())
   }
 
+  pub fn add_log_message<C: AsRef<AddLogMessage>>(&self, add_log_message: C) -> RTDResult<()> {
+    self.api.send(add_log_message.as_ref())
+  }
+
   pub fn add_network_statistics<C: AsRef<AddNetworkStatistics>>(&self, add_network_statistics: C) -> RTDResult<()> {
     self.api.send(add_network_statistics.as_ref())
   }
@@ -157,6 +165,10 @@ impl EventApi {
     self.api.send(check_phone_number_verification_code.as_ref())
   }
 
+  pub fn check_recovery_email_address_code<C: AsRef<CheckRecoveryEmailAddressCode>>(&self, check_recovery_email_address_code: C) -> RTDResult<()> {
+    self.api.send(check_recovery_email_address_code.as_ref())
+  }
+
   pub fn clean_file_name<C: AsRef<CleanFileName>>(&self, clean_file_name: C) -> RTDResult<()> {
     self.api.send(clean_file_name.as_ref())
   }
@@ -381,6 +393,10 @@ impl EventApi {
     self.api.send(get_all_passport_elements.as_ref())
   }
 
+  pub fn get_application_config<C: AsRef<GetApplicationConfig>>(&self, get_application_config: C) -> RTDResult<()> {
+    self.api.send(get_application_config.as_ref())
+  }
+
   pub fn get_archived_sticker_sets<C: AsRef<GetArchivedStickerSets>>(&self, get_archived_sticker_sets: C) -> RTDResult<()> {
     self.api.send(get_archived_sticker_sets.as_ref())
   }
@@ -437,6 +453,10 @@ impl EventApi {
     self.api.send(get_chat_message_count.as_ref())
   }
 
+  pub fn get_chat_notification_settings_exceptions<C: AsRef<GetChatNotificationSettingsExceptions>>(&self, get_chat_notification_settings_exceptions: C) -> RTDResult<()> {
+    self.api.send(get_chat_notification_settings_exceptions.as_ref())
+  }
+
   pub fn get_chat_pinned_message<C: AsRef<GetChatPinnedMessage>>(&self, get_chat_pinned_message: C) -> RTDResult<()> {
     self.api.send(get_chat_pinned_message.as_ref())
   }
@@ -445,6 +465,10 @@ impl EventApi {
     self.api.send(get_chat_report_spam_state.as_ref())
   }
 
+  pub fn get_chat_statistics_url<C: AsRef<GetChatStatisticsUrl>>(&self, get_chat_statistics_url: C) -> RTDResult<()> {
+    self.api.send(get_chat_statistics_url.as_ref())
+  }
+
   pub fn get_chats<C: AsRef<GetChats>>(&self, get_chats: C) -> RTDResult<()> {
     self.api.send(get_chats.as_ref())
   }
@@ -465,6 +489,14 @@ impl EventApi {
     self.api.send(get_created_public_chats.as_ref())
   }
 
+  pub fn get_current_state<C: AsRef<GetCurrentState>>(&self, get_current_state: C) -> RTDResult<()> {
+    self.api.send(get_current_state.as_ref())
+  }
+
+  pub fn get_database_statistics<C: AsRef<GetDatabaseStatistics>>(&self, get_database_statistics: C) -> RTDResult<()> {
+    self.api.send(get_database_statistics.as_ref())
+  }
+
   pub fn get_deep_link_info<C: AsRef<GetDeepLinkInfo>>(&self, get_deep_link_info: C) -> RTDResult<()> {
     self.api.send(get_deep_link_info.as_ref())
   }
@@ -477,6 +509,10 @@ impl EventApi {
     self.api.send(get_file.as_ref())
   }
 
+  pub fn get_file_downloaded_prefix_size<C: AsRef<GetFileDownloadedPrefixSize>>(&self, get_file_downloaded_prefix_size: C) -> RTDResult<()> {
+    self.api.send(get_file_downloaded_prefix_size.as_ref())
+  }
+
   pub fn get_file_extension<C: AsRef<GetFileExtension>>(&self, get_file_extension: C) -> RTDResult<()> {
     self.api.send(get_file_extension.as_ref())
   }
@@ -513,6 +549,18 @@ impl EventApi {
     self.api.send(get_invite_text.as_ref())
   }
 
+  pub fn get_json_string<C: AsRef<GetJsonString>>(&self, get_json_string: C) -> RTDResult<()> {
+    self.api.send(get_json_string.as_ref())
+  }
+
+  pub fn get_json_value<C: AsRef<GetJsonValue>>(&self, get_json_value: C) -> RTDResult<()> {
+    self.api.send(get_json_value.as_ref())
+  }
+
+  pub fn get_language_pack_info<C: AsRef<GetLanguagePackInfo>>(&self, get_language_pack_info: C) -> RTDResult<()> {
+    self.api.send(get_language_pack_info.as_ref())
+  }
+
   pub fn get_language_pack_string<C: AsRef<GetLanguagePackString>>(&self, get_language_pack_string: C) -> RTDResult<()> {
     self.api.send(get_language_pack_string.as_ref())
   }
@@ -525,6 +573,22 @@ impl EventApi {
     self.api.send(get_localization_target_info.as_ref())
   }
 
+  pub fn get_log_stream<C: AsRef<GetLogStream>>(&self, get_log_stream: C) -> RTDResult<()> {
+    self.api.send(get_log_stream.as_ref())
+  }
+
+  pub fn get_log_tag_verbosity_level<C: AsRef<GetLogTagVerbosityLevel>>(&self, get_log_tag_verbosity_level: C) -> RTDResult<()> {
+    self.api.send(get_log_tag_verbosity_level.as_ref())
+  }
+
+  pub fn get_log_tags<C: AsRef<GetLogTags>>(&self, get_log_tags: C) -> RTDResult<()> {
+    self.api.send(get_log_tags.as_ref())
+  }
+
+  pub fn get_log_verbosity_level<C: AsRef<GetLogVerbosityLevel>>(&self, get_log_verbosity_level: C) -> RTDResult<()> {
+    self.api.send(get_log_verbosity_level.as_ref())
+  }
+
   pub fn get_map_thumbnail_file<C: AsRef<GetMapThumbnailFile>>(&self, get_map_thumbnail_file: C) -> RTDResult<()> {
     self.api.send(get_map_thumbnail_file.as_ref())
   }
@@ -537,6 +601,14 @@ impl EventApi {
     self.api.send(get_message.as_ref())
   }
 
+  pub fn get_message_link<C: AsRef<GetMessageLink>>(&self, get_message_link: C) -> RTDResult<()> {
+    self.api.send(get_message_link.as_ref())
+  }
+
+  pub fn get_message_locally<C: AsRef<GetMessageLocally>>(&self, get_message_locally: C) -> RTDResult<()> {
+    self.api.send(get_message_locally.as_ref())
+  }
+
   pub fn get_messages<C: AsRef<GetMessages>>(&self, get_messages: C) -> RTDResult<()> {
     self.api.send(get_messages.as_ref())
   }
@@ -553,6 +625,10 @@ impl EventApi {
     self.api.send(get_passport_authorization_form.as_ref())
   }
 
+  pub fn get_passport_authorization_form_available_elements<C: AsRef<GetPassportAuthorizationFormAvailableElements>>(&self, get_passport_authorization_form_available_elements: C) -> RTDResult<()> {
+    self.api.send(get_passport_authorization_form_available_elements.as_ref())
+  }
+
   pub fn get_passport_element<C: AsRef<GetPassportElement>>(&self, get_passport_element: C) -> RTDResult<()> {
     self.api.send(get_passport_element.as_ref())
   }
@@ -585,6 +661,10 @@ impl EventApi {
     self.api.send(get_public_message_link.as_ref())
   }
 
+  pub fn get_push_receiver_id<C: AsRef<GetPushReceiverId>>(&self, get_push_receiver_id: C) -> RTDResult<()> {
+    self.api.send(get_push_receiver_id.as_ref())
+  }
+
   pub fn get_recent_inline_bots<C: AsRef<GetRecentInlineBots>>(&self, get_recent_inline_bots: C) -> RTDResult<()> {
     self.api.send(get_recent_inline_bots.as_ref())
   }
@@ -741,22 +821,26 @@ impl EventApi {
     self.api.send(parse_text_entities.as_ref())
   }
 
-  pub fn pin_supergroup_message<C: AsRef<PinSupergroupMessage>>(&self, pin_supergroup_message: C) -> RTDResult<()> {
-    self.api.send(pin_supergroup_message.as_ref())
+  pub fn pin_chat_message<C: AsRef<PinChatMessage>>(&self, pin_chat_message: C) -> RTDResult<()> {
+    self.api.send(pin_chat_message.as_ref())
   }
 
   pub fn ping_proxy<C: AsRef<PingProxy>>(&self, ping_proxy: C) -> RTDResult<()> {
     self.api.send(ping_proxy.as_ref())
   }
 
-  pub fn process_dc_update<C: AsRef<ProcessDcUpdate>>(&self, process_dc_update: C) -> RTDResult<()> {
-    self.api.send(process_dc_update.as_ref())
+  pub fn process_push_notification<C: AsRef<ProcessPushNotification>>(&self, process_push_notification: C) -> RTDResult<()> {
+    self.api.send(process_push_notification.as_ref())
   }
 
   pub fn read_all_chat_mentions<C: AsRef<ReadAllChatMentions>>(&self, read_all_chat_mentions: C) -> RTDResult<()> {
     self.api.send(read_all_chat_mentions.as_ref())
   }
 
+  pub fn read_file_part<C: AsRef<ReadFilePart>>(&self, read_file_part: C) -> RTDResult<()> {
+    self.api.send(read_file_part.as_ref())
+  }
+
   pub fn recover_authentication_password<C: AsRef<RecoverAuthenticationPassword>>(&self, recover_authentication_password: C) -> RTDResult<()> {
     self.api.send(recover_authentication_password.as_ref())
   }
@@ -777,6 +861,14 @@ impl EventApi {
     self.api.send(remove_favorite_sticker.as_ref())
   }
 
+  pub fn remove_notification<C: AsRef<RemoveNotification>>(&self, remove_notification: C) -> RTDResult<()> {
+    self.api.send(remove_notification.as_ref())
+  }
+
+  pub fn remove_notification_group<C: AsRef<RemoveNotificationGroup>>(&self, remove_notification_group: C) -> RTDResult<()> {
+    self.api.send(remove_notification_group.as_ref())
+  }
+
   pub fn remove_proxy<C: AsRef<RemoveProxy>>(&self, remove_proxy: C) -> RTDResult<()> {
     self.api.send(remove_proxy.as_ref())
   }
@@ -845,6 +937,10 @@ impl EventApi {
     self.api.send(resend_phone_number_verification_code.as_ref())
   }
 
+  pub fn resend_recovery_email_address_code<C: AsRef<ResendRecoveryEmailAddressCode>>(&self, resend_recovery_email_address_code: C) -> RTDResult<()> {
+    self.api.send(resend_recovery_email_address_code.as_ref())
+  }
+
   pub fn reset_all_notification_settings<C: AsRef<ResetAllNotificationSettings>>(&self, reset_all_notification_settings: C) -> RTDResult<()> {
     self.api.send(reset_all_notification_settings.as_ref())
   }
@@ -853,6 +949,10 @@ impl EventApi {
     self.api.send(reset_network_statistics.as_ref())
   }
 
+  pub fn save_application_log_event<C: AsRef<SaveApplicationLogEvent>>(&self, save_application_log_event: C) -> RTDResult<()> {
+    self.api.send(save_application_log_event.as_ref())
+  }
+
   pub fn search_call_messages<C: AsRef<SearchCallMessages>>(&self, search_call_messages: C) -> RTDResult<()> {
     self.api.send(search_call_messages.as_ref())
   }
@@ -1045,6 +1145,18 @@ impl EventApi {
     self.api.send(set_inline_game_score.as_ref())
   }
 
+  pub fn set_log_stream<C: AsRef<SetLogStream>>(&self, set_log_stream: C) -> RTDResult<()> {
+    self.api.send(set_log_stream.as_ref())
+  }
+
+  pub fn set_log_tag_verbosity_level<C: AsRef<SetLogTagVerbosityLevel>>(&self, set_log_tag_verbosity_level: C) -> RTDResult<()> {
+    self.api.send(set_log_tag_verbosity_level.as_ref())
+  }
+
+  pub fn set_log_verbosity_level<C: AsRef<SetLogVerbosityLevel>>(&self, set_log_verbosity_level: C) -> RTDResult<()> {
+    self.api.send(set_log_verbosity_level.as_ref())
+  }
+
   pub fn set_name<C: AsRef<SetName>>(&self, set_name: C) -> RTDResult<()> {
     self.api.send(set_name.as_ref())
   }
@@ -1073,6 +1185,10 @@ impl EventApi {
     self.api.send(set_pinned_chats.as_ref())
   }
 
+  pub fn set_poll_answer<C: AsRef<SetPollAnswer>>(&self, set_poll_answer: C) -> RTDResult<()> {
+    self.api.send(set_poll_answer.as_ref())
+  }
+
   pub fn set_profile_photo<C: AsRef<SetProfilePhoto>>(&self, set_profile_photo: C) -> RTDResult<()> {
     self.api.send(set_profile_photo.as_ref())
   }
@@ -1113,6 +1229,14 @@ impl EventApi {
     self.api.send(set_username.as_ref())
   }
 
+  pub fn stop_poll<C: AsRef<StopPoll>>(&self, stop_poll: C) -> RTDResult<()> {
+    self.api.send(stop_poll.as_ref())
+  }
+
+  pub fn synchronize_language_pack<C: AsRef<SynchronizeLanguagePack>>(&self, synchronize_language_pack: C) -> RTDResult<()> {
+    self.api.send(synchronize_language_pack.as_ref())
+  }
+
   pub fn terminate_all_other_sessions<C: AsRef<TerminateAllOtherSessions>>(&self, terminate_all_other_sessions: C) -> RTDResult<()> {
     self.api.send(terminate_all_other_sessions.as_ref())
   }
@@ -1201,8 +1325,8 @@ impl EventApi {
     self.api.send(unblock_user.as_ref())
   }
 
-  pub fn unpin_supergroup_message<C: AsRef<UnpinSupergroupMessage>>(&self, unpin_supergroup_message: C) -> RTDResult<()> {
-    self.api.send(unpin_supergroup_message.as_ref())
+  pub fn unpin_chat_message<C: AsRef<UnpinChatMessage>>(&self, unpin_chat_message: C) -> RTDResult<()> {
+    self.api.send(unpin_chat_message.as_ref())
   }
 
   pub fn upgrade_basic_group_chat_to_supergroup_chat<C: AsRef<UpgradeBasicGroupChatToSupergroupChat>>(&self, upgrade_basic_group_chat_to_supergroup_chat: C) -> RTDResult<()> {
@@ -1229,6 +1353,10 @@ impl EventApi {
     self.api.send(view_trending_sticker_sets.as_ref())
   }
 
+  pub fn write_generated_file_part<C: AsRef<WriteGeneratedFilePart>>(&self, write_generated_file_part: C) -> RTDResult<()> {
+    self.api.send(write_generated_file_part.as_ref())
+  }
+
 
 
 }
