@@ -26,6 +26,8 @@ impl Observer {
 
       TdType::TestUseUpdate(value) => value.extra(),
 
+      TdType::UpdateActiveNotifications(value) => value.extra(),
+
       TdType::UpdateAuthorizationState(value) => value.extra(),
 
       TdType::UpdateBasicGroup(value) => value.extra(),
@@ -48,10 +50,14 @@ impl Observer {
 
       TdType::UpdateChatNotificationSettings(value) => value.extra(),
 
+      TdType::UpdateChatOnlineMemberCount(value) => value.extra(),
+
       TdType::UpdateChatOrder(value) => value.extra(),
 
       TdType::UpdateChatPhoto(value) => value.extra(),
 
+      TdType::UpdateChatPinnedMessage(value) => value.extra(),
+
       TdType::UpdateChatReadInbox(value) => value.extra(),
 
       TdType::UpdateChatReadOutbox(value) => value.extra(),
@@ -74,6 +80,8 @@ impl Observer {
 
       TdType::UpdateFileGenerationStop(value) => value.extra(),
 
+      TdType::UpdateHavePendingNotifications(value) => value.extra(),
+
       TdType::UpdateInstalledStickerSets(value) => value.extra(),
 
       TdType::UpdateLanguagePackStrings(value) => value.extra(),
@@ -114,8 +122,14 @@ impl Observer {
 
       TdType::UpdateNewShippingQuery(value) => value.extra(),
 
+      TdType::UpdateNotification(value) => value.extra(),
+
+      TdType::UpdateNotificationGroup(value) => value.extra(),
+
       TdType::UpdateOption(value) => value.extra(),
 
+      TdType::UpdatePoll(value) => value.extra(),
+
       TdType::UpdateRecentStickers(value) => value.extra(),
 
       TdType::UpdateSavedAnimations(value) => value.extra(),
@@ -153,8 +167,12 @@ impl Observer {
 
       TdType::CheckChatUsernameResult(value) => value.extra(),
 
+      TdType::JsonValue(value) => value.extra(),
+
       TdType::LanguagePackStringValue(value) => value.extra(),
 
+      TdType::LogStream(value) => value.extra(),
+
       TdType::OptionValue(value) => value.extra(),
 
       TdType::PassportElement(value) => value.extra(),
@@ -197,6 +215,8 @@ impl Observer {
 
       TdType::CustomRequestResult(value) => value.extra(),
 
+      TdType::DatabaseStatistics(value) => value.extra(),
+
       TdType::DeepLinkInfo(value) => value.extra(),
 
       TdType::EmailAddressAuthenticationCodeInfo(value) => value.extra(),
@@ -205,6 +225,8 @@ impl Observer {
 
       TdType::File(value) => value.extra(),
 
+      TdType::FilePart(value) => value.extra(),
+
       TdType::FormattedText(value) => value.extra(),
 
       TdType::FoundMessages(value) => value.extra(),
@@ -213,14 +235,22 @@ impl Observer {
 
       TdType::Hashtags(value) => value.extra(),
 
+      TdType::HttpUrl(value) => value.extra(),
+
       TdType::ImportedContacts(value) => value.extra(),
 
       TdType::InlineQueryResults(value) => value.extra(),
 
+      TdType::LanguagePackInfo(value) => value.extra(),
+
       TdType::LanguagePackStrings(value) => value.extra(),
 
       TdType::LocalizationTargetInfo(value) => value.extra(),
 
+      TdType::LogTags(value) => value.extra(),
+
+      TdType::LogVerbosityLevel(value) => value.extra(),
+
       TdType::Message(value) => value.extra(),
 
       TdType::Messages(value) => value.extra(),
@@ -235,6 +265,8 @@ impl Observer {
 
       TdType::PassportElements(value) => value.extra(),
 
+      TdType::PassportElementsWithErrors(value) => value.extra(),
+
       TdType::PasswordState(value) => value.extra(),
 
       TdType::PaymentForm(value) => value.extra(),
@@ -249,6 +281,8 @@ impl Observer {
 
       TdType::PublicMessageLink(value) => value.extra(),
 
+      TdType::PushReceiverId(value) => value.extra(),
+
       TdType::RecoveryEmailAddress(value) => value.extra(),
 
       TdType::ScopeNotificationSettings(value) => value.extra(),
@@ -297,6 +331,8 @@ impl Observer {
 
       TdType::TextEntities(value) => value.extra(),
 
+      TdType::Updates(value) => value.extra(),
+
       TdType::User(value) => value.extra(),
 
       TdType::UserFullInfo(value) => value.extra(),
